import java.awt.*;

/**
 * Ein manipulierbares, rechtwinkliges Dreieck, das sich selbst in ein Canvas zeichnet. 
 * 
 * @author	Michael Kolling
 * @version 1.0  (15 July 2000)
 * @reused by	H. Koetter 
 * @v. 1.1 (5 March 2001)
 * @entlehnt und veraendert von der Triangle Klasse von M. Kolling
 */

public class Dreieck
{
    private int height;
    private int width;
	private int xPosition;
	private int yPosition;
	private String color;

    /**
     * Erzeugung eines neuen Dreiecks an einer vordefinierten Position und mit einer vordefinierten Farbe. 
     */
    public Dreieck()
    {
		height = 30;
		width = 40;
		xPosition = 50;
		yPosition = 15;
		color = "green";
		draw();
    }

    /**
     * Verschieben des Dreiecks horizontal um 'distance' Pixel.
     */
    public void moveHorizontal(int distance)
    {
		erase();
		xPosition += distance;
		draw();
    }

    /**
     * Verschieben des Dreiecks vertikal um 'distance' Pixel.
     */
    public void moveVertical(int distance)
    {
		erase();
		yPosition += distance;
		draw();
    }

    /**
     * Aendern von Hoehe und Breite (in Pixels). 
     */
    public void changeSize(int newHeight, int newWidth)
    {
		erase();
		height = newHeight;
		width = newWidth;
		draw();
    }

    /**
     * Neuzeichnen des Rechtecks.
     */
    public void redrawRectangle()
    {
		erase();
		draw();
    }

    /**
     * Wechseln der Farbe. Gueltige Farben sind "red", "yellow", "blue", "green",
     * "magenta" and "black".
     */
    public void changeColor(String newColor)
    {
		color = newColor;
		draw();
    }

	/*
	 * Zeichnen des Dreiecks mit den derzeitigen Werten auf dem Canvas. 
	 */
	private void draw()
	{
		Canvas canvas = Canvas.getCanvas();
		canvas.setForegroundColour(color);
		int[] xpoints = { xPosition, xPosition, xPosition - width };
		int[] ypoints = { yPosition, yPosition + height, yPosition + height };
		canvas.fill(new Polygon(xpoints, ypoints, 3));
		canvas.wait(10);
	}

	/*
	 * Loeschen des Dreiecks auf dem Canvas.
	 */
	private void erase()
	{
		Canvas canvas = Canvas.getCanvas();
		int[] xpoints = { xPosition, xPosition, xPosition - width };
		int[] ypoints = { yPosition, yPosition + height, yPosition + height };
		canvas.erase(new Polygon(xpoints, ypoints, 3));
	}
}
