import java.awt.*;
import java.awt.geom.*;

/**
 * Ein manipulierbarer Kreis, der sich selbst auf ein Canvas zeichnet. 
 * 
 * @author	Michael Kolling
 * @version 1.0  (15 July 2000)
 * reused by H. Koetter with special thanks to Mik
 */

public class Kreis
{
    private int diameter;
	private int xPosition;
	private int yPosition;
	private String color;

    /**
     * Erzeugung eines neuen Kreises an einer vordefinierten Position und mit einer vordefinierten Farbe. 
     */
    public Kreis()
    {
		diameter = 30;
		xPosition = 20;
		yPosition = 60;
		color = "blue";
		draw();
    }

    /**
     * Verschieben des Kreises horizontal um 'distance' Pixel.
     */
    public void moveHorizontal(int distance)
    {
		erase();
		xPosition += distance;
		draw();
    }

    /**
     * Verschieben des Kreises vertikal um 'distance' Pixel.
     */
    public void moveVertical(int distance)
    {
		erase();
		yPosition += distance;
		draw();
    }

    /**
     * Aendern der Groesse ( Radius in Pixel). Die Groesse muss >= 0 sein.
     */
    public void changeSize(int newDiameter)
    {
		erase();
		diameter = newDiameter;
		draw();
    }

    /**
     * Neuzeichnen des Kreises. 
     */
    public void redrawCircle()
    {
		erase();
		draw();
    }

    /**
     * Wechseln der Farbe. Gueltige Farben sind "red", "yellow", "blue", "green",
     * "magenta" and "black".
     */
    public void changeColor(String newColor)
    {
		color = newColor;
		draw();
    }

	/*
	 * Zeichnen des Kreises mit den derzeitigen Werten auf dem Canvas.
	 */
	private void draw()
	{
		Canvas canvas = Canvas.getCanvas();
		canvas.setForegroundColour(color);
		canvas.fill(new Ellipse2D.Double(xPosition, yPosition, 
										 diameter, diameter));
		canvas.wait(10);
	}

	/*
	 * Loeschen des Kreises auf dem Canvas. 
	 */
	private void erase()
	{
		Canvas canvas = Canvas.getCanvas();
		canvas.erase(new Ellipse2D.Double(xPosition, yPosition, 
										 diameter, diameter));
	}
}
